#!/bin/sh
#
# NAME:
#	unshar.sh - unpack shell archives
#
# SYNOPSIS:
#	unshar.sh < file
#	unshar.sh file ...
#
# DESCRIPTION:
#	This script can be used to unpack shell archives
#	contained in mail and news articles.  It looks for a
#	magic line containing one of:
#.nf
#	#!/bin/sh
#	is a shell archive
#	[Rr]emove anything before this line
#.fi
#
#	and feeds the following data to /bin/sh.
#
#	It handles stdin as well as files named on the command
#	line.
#	
# RETURNS:
#	0==success, 1==failure
#
# SEE ALSO:
#	shar.sh
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCS-ID:
#	$Id: unshar.sh,v 1.6 2001/08/30 09:55:59 sjg Exp $
#
#	@(#) Copyright (c) 1992 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

TF=/tmp/unshar.$$
TF2=/tmp/cnshar.$$
copy=

trap exit 1 2 3 15
trap "rm -f $TF $TF2" 0

_unshar ()
{
  f=$1
  sk=`egrep -n '^#(! */bin/sh|.*is a shell archive|.*emove anything before this line)' $f | sed -e 1q`
  magic=`echo $sk | tr / . | cut -d: -f2-`
  sk=`echo $sk | cut -d: -f1`
  if [ $sk -gt 0 ]; then
    if [ "$COPY" ]; then
      # this really sucks...
      # but needed for compatability with a million shar implementations
      tail +$sk $f | sed "/^exit /,/^$magic/d" > $TF2
      /bin/sh $TF2 -c
    else
      tail +$sk $f | sed "/^exit /,/^$magic/d" | /bin/sh
    fi
  fi
}

TRACE=
COPY=
set -- `getopt xc $*`
for i in $*
do
  case $i in
  --)	shift; break;;
  -x)	TRACE=-x; shift;;
  -c)	COPY=yes; shift;;
  esac
done
if [ $# -gt 0 ]; then
  for f in $*
  do
    _unshar $f
  done
else
  cat - > $TF
  _unshar $TF
fi  
